@@ -1,6 +1,5 @@
 /*
  * Copyright (C) 2021 Purism SPC
- * Copyright (C) 2024 GNOME Foundation, Inc.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  *
@@ -40,7 +39,6 @@ struct _HdySettings
     COLOR_SCHEME_STATE_NONE
   } color_scheme_portal_state;
   enum {
-    HIGH_CONTRAST_STATE_FDO,
     HIGH_CONTRAST_STATE_GNOME,
     HIGH_CONTRAST_STATE_NONE
   } high_contrast_portal_state;
@@ -241,20 +239,12 @@ settings_portal_changed_cb (GDBusProxy  *proxy,
 
   g_variant_get (parameters, "(&s&sv)", &namespace, &name, &value);
 
-  if (!g_strcmp0 (namespace, "org.freedesktop.appearance")) {
-    if (!g_strcmp0 (name, "color-scheme") &&
-        self->color_scheme_portal_state == COLOR_SCHEME_STATE_FDO) {
-      set_color_scheme (self, get_fdo_color_scheme (value));
+  if (!g_strcmp0 (namespace, "org.freedesktop.appearance") &&
+      !g_strcmp0 (name, "color-scheme") &&
+      self->color_scheme_portal_state == COLOR_SCHEME_STATE_FDO) {
+    set_color_scheme (self, get_fdo_color_scheme (value));
 
-      return;
-    }
-
-    if (!g_strcmp0 (name, "contrast") &&
-        self->high_contrast_portal_state == HIGH_CONTRAST_STATE_FDO) {
-      set_high_contrast (self, g_variant_get_uint32 (value) == 1);
-
-      return;
-    }
+    return;
   }
 
   if (!g_strcmp0 (namespace, "org.gnome.desktop.interface") &&
@@ -314,14 +304,6 @@ init_portal (HdySettings *self)
     self->color_scheme = get_gnome_color_scheme (color_scheme_variant);
   }
 
-  if (!self->has_high_contrast &&
-      read_portal_setting (self, "org.freedesktop.appearance",
-                           "contrast", "u", &high_contrast_variant)) {
-    self->has_high_contrast = TRUE;
-    self->high_contrast_portal_state = HIGH_CONTRAST_STATE_FDO;
-    self->high_contrast = g_variant_get_uint32 (high_contrast_variant) == 1;
-  }
-
   if (!self->has_high_contrast &&
       read_portal_setting (self, "org.gnome.desktop.a11y.interface",
                            "high-contrast", "b", &high_contrast_variant)) {
